@@ -27,7 +27,7 @@ ui <- fluidPage(
 secure_ui(
   ui,
   sign_in_page_ui = sign_in_ui_default(
-    sign_in_no_invite_module_ui("sign_in")
+    sign_in_module_2_ui("sign_in")
   )
 )
 
